@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use strict;
 use warnings;
@@ -85,17 +85,17 @@ sub voicings {
     $chord_name //= '';
     $format ||= '';
     my $voicings = $self->chords->{ 'C' . $chord_name };
-    if ($format eq 'ISO') {
-        my $iso;
+    if ($format) {
+        my $temp;
         for my $chord (@$voicings) {
             my $span;
             for my $n (@$chord) {
-                my $note = Music::Note->new($n, 'midinum')->format('ISO');
+                my $note = Music::Note->new($n, 'midinum')->format($format);
                 push @$span, $note;
             }
-            push @$iso, $span;
+            push @$temp, $span;
         }
-        $voicings = $iso;
+        $voicings = $temp;
     }
     return $voicings;
 }
@@ -114,7 +114,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -209,8 +209,8 @@ given, C<0> is used.
   $mcg->voicings($chord_name, $format);
 
 Return all the voicings of a given B<chord_name>.  The default
-B<format> is C<midinum> but can be given as C<ISO> to return named
-notes with octaves.
+B<format> is C<midinum> but can be given as C<ISO> or C<midi> to
+return named notes with octaves.
 
 The order of the voicing variations of a chord is by fret position.
 So, the first variations are at lower frets.  Please use the above
